const electron = require('electron');
const app = electron.app;
const BrowserWindow = electron.BrowserWindow;
const Menu = electron.Menu;
const dialog = electron.dialog;
const ipcMain = electron.ipcMain;

let mainWindow = null;
let settingsWindow = null;
let exportWindow = null;
let importWindow = null;
// let backgroundColor = 'skyblue';
var force_quit = false;

let menuTemplate = [{
    label: 'iPassKeeper',
    submenu: [
      { label: 'このアプリについて', accelerator: 'CmdOrCtrl+Shift+A', click: function() { showAboutDialog(); } },
      { type:  'separator' },
      { label: '設定', accelerator: 'CmdOrCtrl+,', click: function() { showSettingsWindow(); } },
      { type:  'separator' },
      { label: 'パスワードを生成する', accelerator: 'CmdOrCtrl+Shift+C', click: function() { makePasswordAtIndex(); } },
      { type:  'separator'},
      { label: '終了する' , accelerator: 'CmdOrCtrl+Q', click: function() { app.quit(); }},
    ]
  },{
    label: "ファイル",
    submenu: [
     { label: "新規フォルダ", accelerator: "Shift+CmdOrCtrl+N", click: function() { mainWindow.webContents.send("create_newfolder","_")} },
     { label: "新規ファイル", accelerator: "CmdOrCtrl+N", click: function() { mainWindow.webContents.send("create_newfile","_")} },
     { type: "separator" },
     { label: "閉じる", accelerator: "CmdOrCtrl+W", role: 'close' }, // click: function() { close_window() } },
     { label: "保存する", accelerator: "CmdOrCtrl+S", click: function() { mainWindow.webContents.send("preserve_ip","_") }},
     { type: "separator" },
     { label: "インポート", accelerator: "CmdOrCtrl+I", click: function() { mainWindow.webContents.send("import_ip","_") }},
     { label: "エクスポート", accelerator: "CmdOrCtrl+E", click: function() { mainWindow.webContents.send("export_ip","_") }}
    ]
  }, {
    label: "編集",
    submenu: [
     { label: "取り消す", accelerator: "CmdOrCtrl+Z", selector: "undo:" },
     { label: "やり直す", accelerator: "Shift+CmdOrCtrl+Z", selector: "redo:" },
     { type: "separator" },
     { label: "カット", accelerator: "CmdOrCtrl+X", selector: "cut:" },
     { label: "コピー", accelerator: "CmdOrCtrl+C", selector: "copy:" },
     { label: "ペースト", accelerator: "CmdOrCtrl+V", selector: "paste:" },
     { label: "すべてを選択", accelerator: "CmdOrCtrl+A", selector: "selectAll:" }
    ]
  }, {
    label: "ウィンドウ",
    submenu: [
      { label: "最小化", accelerator: "CmdOrCtrl+M", role: 'minimize'}
    ]
  }
];

let menu = Menu.buildFromTemplate(menuTemplate);

// ipcMain.on('settings_changed', function(event, color) {
//   mainWindow.webContents.send('set_bgcolor', color);
// });

// ipcMain.on('bgcolor_changed', function(event, color) {
//   backgroundColor = color;
// });

// ipcMain.on('get_bgcolor', function(event){
//   event.returnValue = backgroundColor;
// })

ipcMain.on('export_iphash', function(event, message) {
  exportWindow = new BrowserWindow({width: 450, height: 350, parent: mainWindow});
  exportWindow.loadURL('file://' + __dirname + '/export.html');
  // exportWindow.webContents.openDevTools();
  exportWindow.show();
  exportWindow.on('closed', function() {
    exportWindow = null;
  });
});

ipcMain.on('import_screen', function(event, message) {
  importWindow = new BrowserWindow({width: 450, height: 350, parent: mainWindow});
  importWindow.loadURL('file://' + __dirname + '/import.html');
  // importWindow.webContents.openDevTools();
  importWindow.show();
  importWindow.on('closed', function() {
    importWindow = null;
  });
});

ipcMain.on('import_start', function(event, message) {
  mainWindow.webContents.send('import_start', 'tsv check is OK ^q^');
})

function makePasswordAtIndex() {
  mainWindow.webContents.send('make_password', "make random password");
}

function showAboutDialog() {
  dialog.showMessageBox({
    type: 'info',
    buttons: ['OK'],
    message: 'このアプリについて',
    detail: 'This app was created by Nishimoto'
  })
}

function showSettingsWindow() {
  settingsWindow = new BrowserWindow({width: 400, height: 300, parent: mainWindow});
  settingsWindow.loadURL('file://' + __dirname + '/settings.html');
  // settingsWindow.webContents.openDevTools();
  settingsWindow.show();
  settingsWindow.on('closed', function() {
    settingsWindow = null;
  });
}

function createMainWindow() {
  Menu.setApplicationMenu(menu);
  mainWindow = new BrowserWindow({width: 660, height: 750, maxWidth: 670, maxHeight: 760, minWidth: 650, minHeight: 490});
  mainWindow.loadURL('file://' + __dirname + '/login.html');
  // mainWindow.webContents.openDevTools();
  mainWindow.on('close', function(e) {
    if (!force_quit) {
      e.preventDefault();
      mainWindow.hide();
    }
  })
}

app.on('ready', () => {
  createMainWindow();
});

app.on('window-all-closed', function(e) {
  if (process.platform != "darwin") {
    app_quit();
  }
})

app.on('before-quit', function(e) {
  mainWindow.webContents.send('encrypt_tree', 'encrypt_tree');
  force_quit = true;
})

app.on('activate', function() {
  if (mainWindow == null) {
    createMainWindow();
  } else {
    mainWindow.show();
  }
});